@@ -104,7 +104,7 @@ echo ""
 echo "You will now have to take one of the following actions"
 echo "to make PostgreSQL recognize some of the changes:"
 echo ""
-echo "- run systemctl stop postgresql.service && systemctl start postgresql.service"
+echo "- run 'systemctl stop postgresql.service && systemctl start postgresql.service'"
 echo "- run '/etc/init.d/postgresql reload (adjust to version)'"
 echo "- run 'pg_ctlcluster <version> <name> reload'"
 echo "- run 'pg_ctl reload'"
