@@ -647,10 +647,11 @@ def format_interval_medically(interval=None):
 	This isn't mathematically correct but close enough for display.
 	"""
 	# more than 1 year ?
-	if interval.days > 363:
-		years, days = divmod(interval.days, 364)
+	if interval.days > 364:
+		years, days = divmod(interval.days, avg_days_per_gregorian_year)
 		leap_days, tmp = divmod(years, 4)
-		months, day = divmod((days + leap_days), 30.33)
+		days_left_without_leap_days = days - leap_days
+		months, day = divmod((days_left_without_leap_days), 30.33)
 		if int(months) == 0:
 			return "%s%s" % (int(years), _('interval_format_tag::years::y')[-1:])
 		return "%s%s %s%s" % (int(years), _('interval_format_tag::years::y')[-1:], int(months), _('interval_format_tag::months::m')[-1:])
@@ -710,7 +711,7 @@ def format_pregnancy_weeks(age):
 	return '%s%s%s%s' % (
 		int(weeks),
 		_('interval_format_tag::weeks::w')[-1:],
-		interval.days,
+		days,
 		_('interval_format_tag::days::d')[-1:]
 	)
 
@@ -976,62 +977,62 @@ def str2interval(str_interval=None):
 
 	# "(~)35(yY)"	- at age 35 years
 	keys = '|'.join(list(unit_keys['year'].replace('_keys_year', '')))
-	if regex.match('^~*(\s|\t)*\d+(%s)*$' % keys, str_interval, flags = regex.UNICODE):
-		return pyDT.timedelta(days = (int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]) * avg_days_per_gregorian_year))
+	if regex.match(r'^~*(\s|\t)*\d+(%s)*$' % keys, str_interval, flags = regex.UNICODE):
+		return pyDT.timedelta(days = (int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]) * avg_days_per_gregorian_year))
 
 	# "(~)12mM" - at age 12 months
 	keys = '|'.join(list(unit_keys['month'].replace('_keys_month', '')))
-	if regex.match('^~*(\s|\t)*\d+(\s|\t)*(%s)+$' % keys, str_interval, flags = regex.UNICODE):
+	if regex.match(r'^~*(\s|\t)*\d+(\s|\t)*(%s)+$' % keys, str_interval, flags = regex.UNICODE):
 		years, months = divmod (
-			int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]),
+			int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]),
 			12
 		)
 		return pyDT.timedelta(days = ((years * avg_days_per_gregorian_year) + (months * avg_days_per_gregorian_month)))
 
 	# weeks
 	keys = '|'.join(list(unit_keys['week'].replace('_keys_week', '')))
-	if regex.match('^~*(\s|\t)*\d+(\s|\t)*(%s)+$' % keys, str_interval, flags = regex.UNICODE):
-		return pyDT.timedelta(weeks = int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]))
+	if regex.match(r'^~*(\s|\t)*\d+(\s|\t)*(%s)+$' % keys, str_interval, flags = regex.UNICODE):
+		return pyDT.timedelta(weeks = int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]))
 
 	# days
 	keys = '|'.join(list(unit_keys['day'].replace('_keys_day', '')))
-	if regex.match('^~*(\s|\t)*\d+(\s|\t)*(%s)+$' % keys, str_interval, flags = regex.UNICODE):
-		return pyDT.timedelta(days = int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]))
+	if regex.match(r'^~*(\s|\t)*\d+(\s|\t)*(%s)+$' % keys, str_interval, flags = regex.UNICODE):
+		return pyDT.timedelta(days = int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]))
 
 	# hours
 	keys = '|'.join(list(unit_keys['hour'].replace('_keys_hour', '')))
-	if regex.match('^~*(\s|\t)*\d+(\s|\t)*(%s)+$' % keys, str_interval, flags = regex.UNICODE):
-		return pyDT.timedelta(hours = int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]))
+	if regex.match(r'^~*(\s|\t)*\d+(\s|\t)*(%s)+$' % keys, str_interval, flags = regex.UNICODE):
+		return pyDT.timedelta(hours = int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]))
 
 	# x/12 - months
-	if regex.match('^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*12$', str_interval, flags = regex.UNICODE):
+	if regex.match(r'^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*12$', str_interval, flags = regex.UNICODE):
 		years, months = divmod (
-			int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]),
+			int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]),
 			12
 		)
 		return pyDT.timedelta(days = ((years * avg_days_per_gregorian_year) + (months * avg_days_per_gregorian_month)))
 
 	# x/52 - weeks
-	if regex.match('^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*52$', str_interval, flags = regex.UNICODE):
-		return pyDT.timedelta(weeks = int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]))
+	if regex.match(r'^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*52$', str_interval, flags = regex.UNICODE):
+		return pyDT.timedelta(weeks = int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]))
 
 	# x/7 - days
-	if regex.match('^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*7$', str_interval, flags = regex.UNICODE):
-		return pyDT.timedelta(days = int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]))
+	if regex.match(r'^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*7$', str_interval, flags = regex.UNICODE):
+		return pyDT.timedelta(days = int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]))
 
 	# x/24 - hours
-	if regex.match('^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*24$', str_interval, flags = regex.UNICODE):
-		return pyDT.timedelta(hours = int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]))
+	if regex.match(r'^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*24$', str_interval, flags = regex.UNICODE):
+		return pyDT.timedelta(hours = int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]))
 
 	# x/60 - minutes
-	if regex.match('^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*60$', str_interval, flags = regex.UNICODE):
-		return pyDT.timedelta(minutes = int(regex.findall('\d+', str_interval, flags = regex.UNICODE)[0]))
+	if regex.match(r'^~*(\s|\t)*\d+(\s|\t)*/(\s|\t)*60$', str_interval, flags = regex.UNICODE):
+		return pyDT.timedelta(minutes = int(regex.findall(r'\d+', str_interval, flags = regex.UNICODE)[0]))
 
 	# nYnM - years, months
 	keys_year = '|'.join(list(unit_keys['year'].replace('_keys_year', '')))
 	keys_month = '|'.join(list(unit_keys['month'].replace('_keys_month', '')))
-	if regex.match('^~*(\s|\t)*\d+(%s|\s|\t)+\d+(\s|\t)*(%s)+$' % (keys_year, keys_month), str_interval, flags = regex.UNICODE):
-		parts = regex.findall('\d+', str_interval, flags = regex.UNICODE)
+	if regex.match(r'^~*(\s|\t)*\d+(%s|\s|\t)+\d+(\s|\t)*(%s)+$' % (keys_year, keys_month), str_interval, flags = regex.UNICODE):
+		parts = regex.findall(r'\d+', str_interval, flags = regex.UNICODE)
 		years, months = divmod(int(parts[1]), 12)
 		years += int(parts[0])
 		return pyDT.timedelta(days = ((years * avg_days_per_gregorian_year) + (months * avg_days_per_gregorian_month)))
@@ -1039,8 +1040,8 @@ def str2interval(str_interval=None):
 	# nMnW - months, weeks
 	keys_month = '|'.join(list(unit_keys['month'].replace('_keys_month', '')))
 	keys_week = '|'.join(list(unit_keys['week'].replace('_keys_week', '')))
-	if regex.match('^~*(\s|\t)*\d+(%s|\s|\t)+\d+(\s|\t)*(%s)+$' % (keys_month, keys_week), str_interval, flags = regex.UNICODE):
-		parts = regex.findall('\d+', str_interval, flags = regex.UNICODE)
+	if regex.match(r'^~*(\s|\t)*\d+(%s|\s|\t)+\d+(\s|\t)*(%s)+$' % (keys_month, keys_week), str_interval, flags = regex.UNICODE):
+		parts = regex.findall(r'\d+', str_interval, flags = regex.UNICODE)
 		months, weeks = divmod(int(parts[1]), 4)
 		months += int(parts[0])
 		return pyDT.timedelta(days = ((months * avg_days_per_gregorian_month) + (weeks * days_per_week)))
@@ -1536,22 +1537,6 @@ def str2pydt_matches(str2parse=None, patterns=None):
 	matches.extend(__single_char2py_dt(str2parse))
 	matches.extend(__explicit_offset2py_dt(str2parse))
 
-	# no more with Python3
-#	# try mxDT parsers
-#	try:
-#		date = mxDT.Parser.DateFromString (
-#			text = str2parse,
-#			formats = ('euro', 'iso', 'us', 'altus', 'altiso', 'lit', 'altlit', 'eurlit')
-#		)
-#		matches.append ({
-#			'data': mxdt2py_dt(date),
-#			'label': date.strftime('%Y-%m-%d')
-#		})
-#	except (ValueError, OverflowError):
-#		pass
-#	except mxDT.RangeError:
-#		pass
-
 	# apply explicit patterns
 	if patterns is None:
 		patterns = []
@@ -1574,12 +1559,27 @@ def str2pydt_matches(str2parse=None, patterns=None):
 
 	patterns.append('%Y.%m.%d')
 
+	parts = str2parse.split(maxsplit = 1)
+	hour = 11
+	minute = 11
+	second = 11
+	if len(parts) > 1:
+		for pattern in ['%H:%M', '%H:%M:%S']:
+			try:
+				date = pyDT.datetime.strptime(parts[1], pattern)
+				hour = date.hour
+				minute = date.minute
+				second = date.second
+				break
+			except ValueError:
+				# C-level overflow
+				continue
 	for pattern in patterns:
 		try:
-			date = pyDT.datetime.strptime(str2parse, pattern).replace (
-				hour = 11,
-				minute = 11,
-				second = 11,
+			date = pyDT.datetime.strptime(parts[0], pattern).replace (
+				hour = hour,
+				minute = minute,
+				second = second,
 				tzinfo = gmCurrentLocalTimezone
 			)
 			matches.append ({
@@ -1590,6 +1590,7 @@ def str2pydt_matches(str2parse=None, patterns=None):
 			# C-level overflow
 			continue
 
+
 	return matches
 
 #===========================================================================
@@ -1614,8 +1615,8 @@ def __single_slash(str2parse):
 	matches = []
 	now = pydt_now_here()
 	# "xx/yyyy"
-	if regex.match("^(\s|\t)*\d{1,2}(\s|\t)*/+(\s|\t)*\d{4}(\s|\t)*$", str2parse, flags = regex.UNICODE):
-		parts = regex.findall('\d+', str2parse, flags = regex.UNICODE)
+	if regex.match(r"^(\s|\t)*\d{1,2}(\s|\t)*/+(\s|\t)*\d{4}(\s|\t)*$", str2parse, flags = regex.UNICODE):
+		parts = regex.findall(r'\d+', str2parse, flags = regex.UNICODE)
 		month = int(parts[0])
 		if month in range(1, 13):
 			fts = cFuzzyTimestamp (
@@ -1627,8 +1628,8 @@ def __single_slash(str2parse):
 				'label': fts.format_accurately()
 			})
 	# "xx/"
-	elif regex.match("^(\s|\t)*\d{1,2}(\s|\t)*/+(\s|\t)*$", str2parse, flags = regex.UNICODE):
-		val = int(regex.findall('\d+', str2parse, flags = regex.UNICODE)[0])
+	elif regex.match(r"^(\s|\t)*\d{1,2}(\s|\t)*/+(\s|\t)*$", str2parse, flags = regex.UNICODE):
+		val = int(regex.findall(r'\d+', str2parse, flags = regex.UNICODE)[0])
 
 		if val < 100 and val >= 0:
 			matches.append ({
@@ -1696,14 +1697,15 @@ def __numbers_only(str2parse):
 
 	Spaces or tabs are discarded.
 	"""
-	if not regex.match("^(\s|\t)*\d{1,4}(\s|\t)*$", str2parse, flags = regex.UNICODE):
+	if not regex.match(r"^(\s|\t)*\d{1,4}(\s|\t)*$", str2parse, flags = regex.UNICODE):
+		return []
+
+	val = int(regex.findall(r'\d{1,4}', str2parse, flags = regex.UNICODE)[0])
+	if val == 0:
 		return []
 
 	now = pydt_now_here()
-	val = int(regex.findall('\d{1,4}', str2parse, flags = regex.UNICODE)[0])
-
 	matches = []
-
 	# today in that year
 	if (1850 < val) and (val < 2100):
 		target_date = cFuzzyTimestamp (
@@ -1943,65 +1945,50 @@ def str2fuzzy_timestamp_matches(str2parse=None, default_time=None, patterns=None
 		} for m in __explicit_offset2py_dt(str2parse)
 	])
 
-	# reactivate, once mxDT becomes available on Py3k
-#	# try mxDT parsers
-#	try:
-#		# date ?
-#		date_only = mxDT.Parser.DateFromString (
-#			text = str2parse,
-#			formats = ('euro', 'iso', 'us', 'altus', 'altiso', 'lit', 'altlit', 'eurlit')
-#		)
-#		# time, too ?
-#		time_part = mxDT.Parser.TimeFromString(text = str2parse)
-#		datetime = date_only + time_part
-#		if datetime == date_only:
-#			accuracy = acc_days
-#			if isinstance(default_time, mxDT.DateTimeDeltaType):
-#				datetime = date_only + default_time
-#				accuracy = acc_minutes
-#		else:
-#			accuracy = acc_subseconds
-#		fts = cFuzzyTimestamp (
-#			timestamp = datetime,
-#			accuracy = accuracy
-#		)
-#		matches.append ({
-#			'data': fts,
-#			'label': fts.format_accurately()
-#		})
-#	except ValueError:
-#		pass
-#	except mxDT.RangeError:
-#		pass
-
 	if patterns is None:
 		patterns = []
 	patterns.extend([
-		['%Y-%m-%d', acc_days],
-		['%y-%m-%d', acc_days],
-		['%Y/%m/%d', acc_days],
-		['%y/%m/%d', acc_days],
-
-		['%d-%m-%Y', acc_days],
-		['%d-%m-%y', acc_days],
-		['%d/%m/%Y', acc_days],
-		['%d/%m/%y', acc_days],
-		['%d.%m.%Y', acc_days],
-
-		['%m-%d-%Y', acc_days],
-		['%m-%d-%y', acc_days],
-		['%m/%d/%Y', acc_days],
-		['%m/%d/%y', acc_days]
+		'%Y-%m-%d',
+		'%y-%m-%d',
+		'%Y/%m/%d',
+		'%y/%m/%d',
+		'%d-%m-%Y',
+		'%d-%m-%y',
+		'%d/%m/%Y',
+		'%d/%m/%y',
+		'%d.%m.%Y',
+		'%m-%d-%Y',
+		'%m-%d-%y',
+		'%m/%d/%Y',
+		'%m/%d/%y'
 	])
+
+	parts = str2parse.split(maxsplit = 1)
+	hour = 11
+	minute = 11
+	second = 11
+	acc = acc_days
+	if len(parts) > 1:
+		for pattern in ['%H:%M', '%H:%M:%S']:
+			try:
+				date = pyDT.datetime.strptime(parts[1], pattern)
+				hour = date.hour
+				minute = date.minute
+				second = date.second
+				acc = acc_minutes
+				break
+			except ValueError:
+				# C-level overflow
+				continue
 	for pattern in patterns:
 		try:
-			ts = pyDT.datetime.strptime(str2parse, pattern[0]).replace (
-				hour = 11,
-				minute = 11,
-				second = 11,
+			ts = pyDT.datetime.strptime(parts[0], pattern).replace (
+				hour = hour,
+				minute = minute,
+				second = second,
 				tzinfo = gmCurrentLocalTimezone
 			)
-			fts = cFuzzyTimestamp(timestamp = ts, accuracy = pattern[1])
+			fts = cFuzzyTimestamp(timestamp = ts, accuracy = acc)
 			matches.append ({
 				'data': fts,
 				'label': fts.format_accurately()
@@ -2009,7 +1996,6 @@ def str2fuzzy_timestamp_matches(str2parse=None, default_time=None, patterns=None
 		except ValueError:
 			# C-level overflow
 			continue
-
 	return matches
 
 #===========================================================================
@@ -2234,10 +2220,9 @@ if __name__ == '__main__':
 			pyDT.timedelta(days = 366),
 			pyDT.timedelta(days = 367),
 			pyDT.timedelta(days = 400),
-			pyDT.timedelta(weeks = 52 * 30),
-			pyDT.timedelta(weeks = 52 * 79, days = 33)
+			pyDT.timedelta(weeks = 53 * 30),
+			pyDT.timedelta(weeks = 53 * 79, days = 33)
 		]
-
 		idx = 1
 		for intv in intervals:
 			print ('%s) %s -> %s' % (idx, intv, format_interval_medically(intv)))
@@ -2401,7 +2386,7 @@ if __name__ == '__main__':
 	#-------------------------------------------------
 	def test_get_date_of_weekday_in_week_of_date():
 		dt = pydt_now_here()
-		print('weekday', base_dt.isoweekday(), '(2day):', dt)
+		print('weekday', dt.isoweekday(), '(2day):', dt)
 		for weekday in range(8):
 			dt = get_date_of_weekday_in_week_of_date(weekday)
 			print('weekday', weekday, '(same):', dt)
@@ -2416,6 +2401,15 @@ if __name__ == '__main__':
 		except ValueError as exc:
 			print(exc)
 
+	#-------------------------------------------------
+	def test__numbers_only():
+		for val in range(-1, 35):
+			matches = __numbers_only(str(val))
+			print(val, ':')
+			for m in matches:
+				print('  ', m)
+			input()
+
 	#-------------------------------------------------
 	# GNUmed libs
 	gmI18N.activate_locale()
@@ -2434,6 +2428,7 @@ if __name__ == '__main__':
 	#test_str2pydt()
 	#test_pydt_strftime()
 	#test_calculate_apparent_age()
-	test_is_leap_year()
+	#test_is_leap_year()
+	test__numbers_only()
 
 #===========================================================================
