@@ -1,20 +1,12 @@
 -- Project: GNUmed
 -- ===================================================================
--- $Source: /home/ncq/Projekte/cvs2git/vcs-mirror/gnumed/gnumed/server/sql/country.specific/au/gmDemographics.au.sql,v $
--- $Revision: 1.15 $
 -- license: GPL v2 or later
 -- authors: Ian Haywood, Horst Herb, Karsten Hilbert, Richard Terry
 
--- demographics tables specific fr Australia
-
 -- ===================================================================
 -- force terminate + exit(3) on errors if non-interactive
 \set ON_ERROR_STOP 1
 
-reset client_encoding;
--- ===================================================================
-
-
 -- ===================================================================
 
 -- seeding for occupations list
@@ -92,60 +84,3 @@ INSERT INTO dem.enum_ext_id_types (name, issuer, context) VALUES ('ur_no', 'dbf
 -- do simple schema revision tracking
 delete from gm_schema_revision where filename='$RCSfile: gmDemographics.au.sql,v $';
 INSERT INTO gm_schema_revision (filename, version) VALUES('$RCSfile: gmDemographics.au.sql,v $', '$Revision: 1.15 $');
-
--- ===================================================================
--- $Log: gmDemographics.au.sql,v $
--- Revision 1.15  2006-07-04 14:18:04  ncq
--- - add two ext id types
---
--- Revision 1.14  2006/01/06 10:12:02  ncq
--- - add missing grants
--- - add_table_for_audit() now in "audit" schema
--- - demographics now in "dem" schema
--- - add view v_inds4vaccine
--- - move staff_role from clinical into demographics
--- - put add_coded_term() into "clin" schema
--- - put German things into "de_de" schema
---
--- Revision 1.13  2005/09/19 16:38:51  ncq
--- - adjust to removed is_core from gm_schema_revision
---
--- Revision 1.12  2005/07/14 21:31:42  ncq
--- - partially use improved schema revision tracking
---
--- Revision 1.11  2004/06/17 11:31:07  ihaywood
--- A new form template for the new form markup.
--- Basically @...@ where any Python expression can exist
--- between the "@" signs. The other form templates will be changed over eventually.
---
--- Revision 1.10  2004/03/04 19:41:52  ncq
--- - whitespace, comment
---
--- Revision 1.9  2004/03/04 10:48:06  ncq
--- - don't hardcode primary keys for ext_id_types
---
--- Revision 1.8  2004/03/03 23:50:58  ihaywood
--- external ID types for Australia.
---
--- Revision 1.7  2004/03/02 10:22:41  ihaywood
--- support for martial status and occupations
--- .conf files now use host autoprobing
---
--- Revision 1.6  2004/01/05 00:59:14  ncq
--- - remove ourselves from schema revision table
---
--- Revision 1.5  2003/12/29 15:49:46  uid66147
--- - reset client_encoding
---
--- Revision 1.4  2003/10/01 16:12:01  ncq
--- - AU -> au
---
--- Revision 1.3  2003/10/01 15:45:20  ncq
--- - use add_table_for_audit() instead of inheriting from audit_mark
---
--- Revision 1.2  2003/08/17 00:27:33  ncq
--- - log_ tables removed, now auto-created
---
--- Revision 1.1  2003/08/05 09:24:51  ncq
--- - first checkin
---
