@@ -6,9 +6,6 @@
 --
 -- ==============================================================
 \set ON_ERROR_STOP 1
-set check_function_bodies to on;
-
---set default_transaction_read_only to off;
 
 -- --------------------------------------------------------------
 \unset ON_ERROR_STOP
