@@ -13,7 +13,7 @@ drop index if exists dem.idx_dem_org_fk_category cascade;
 create index idx_dem_org_fk_category on dem.org(fk_category);
 
 drop index if exists dem.idx_trgm_dem_org_desc cascade;
-create index idx_trgm_dem_org_desc on dem.org using gin (description gin_trgm_ops);
+create index idx_trgm_dem_org_desc on dem.org using gin (description pgtrgm.gin_trgm_ops);
 
 -- --------------------------------------------------------------
 drop index if exists dem.idx_dem_org_unit_fk_category cascade;
@@ -23,7 +23,7 @@ drop index if exists dem.idx_dem_org_unit_fk_address cascade;
 create index idx_dem_org_unit_fk_address on dem.org_unit(fk_address);
 
 drop index if exists dem.idx_trgm_dem_org_unit_desc cascade;
-create index idx_trgm_dem_org_unit_desc on dem.org_unit using gin (description gin_trgm_ops);
+create index idx_trgm_dem_org_unit_desc on dem.org_unit using gin (description pgtrgm.gin_trgm_ops);
 
 -- --------------------------------------------------------------
-select gm.log_script_insertion('v19-dem-org-idx-fixup.sql', '19.9');
+select gm.log_script_insertion('v19-dem-org-idx-fixup.sql', '19.12');
